Class: Google::Apis::SecretmanagerV1beta1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/secretmanager_v1beta1/classes.rb,
lib/google/apis/secretmanager_v1beta1/representations.rb,
lib/google/apis/secretmanager_v1beta1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



614
615
616
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


572
573
574
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 572

def api_version
  @api_version
end

#create_timeString

Output only. Time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


577
578
579
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 577

def create_time
  @create_time
end

#end_timeString

Output only. Time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


582
583
584
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 582

def end_time
  @end_time
end

#progressGoogle::Apis::SecretmanagerV1beta1::Progress

Represents progress information for operations involving multiple secret versions. Corresponds to the JSON property progress



588
589
590
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 588

def progress
  @progress
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


596
597
598
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 596

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


602
603
604
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 602

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


607
608
609
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 607

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


612
613
614
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 612

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



619
620
621
622
623
624
625
626
627
628
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 619

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @progress = args[:progress] if args.key?(:progress)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end