Class: Google::Apis::SecretmanagerV1beta1::ResourcePolicyMember
- Inherits:
-
Object
- Object
- Google::Apis::SecretmanagerV1beta1::ResourcePolicyMember
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/secretmanager_v1beta1/classes.rb,
lib/google/apis/secretmanager_v1beta1/representations.rb,
lib/google/apis/secretmanager_v1beta1/representations.rb
Overview
Output-only policy member strings of a Google Cloud resource's built-in identity.
Instance Attribute Summary collapse
-
#iam_policy_name_principal ⇒ String
Output only.
-
#iam_policy_uid_principal ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyMember
constructor
A new instance of ResourcePolicyMember.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyMember
Returns a new instance of ResourcePolicyMember.
829 830 831 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 829 def initialize(**args) update!(**args) end |
Instance Attribute Details
#iam_policy_name_principal ⇒ String
Output only. IAM policy binding member referring to a Google Cloud resource by
user-assigned name (https://google.aip.dev/122). If a resource is deleted and
recreated with the same name, the binding will be applicable to the new
resource. Example: principal://parametermanager.googleapis.com/projects/12345/
name/locations/us-central1-a/parameters/my-parameter
Corresponds to the JSON property iamPolicyNamePrincipal
818 819 820 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 818 def iam_policy_name_principal @iam_policy_name_principal end |
#iam_policy_uid_principal ⇒ String
Output only. IAM policy binding member referring to a Google Cloud resource by
system-assigned unique identifier (https://google.aip.dev/148#uid). If a
resource is deleted and recreated with the same name, the binding will not be
applicable to the new resource Example: principal://parametermanager.
googleapis.com/projects/12345/uid/locations/us-central1-a/parameters/a918fed5
Corresponds to the JSON property iamPolicyUidPrincipal
827 828 829 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 827 def iam_policy_uid_principal @iam_policy_uid_principal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
834 835 836 837 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 834 def update!(**args) @iam_policy_name_principal = args[:iam_policy_name_principal] if args.key?(:iam_policy_name_principal) @iam_policy_uid_principal = args[:iam_policy_uid_principal] if args.key?(:iam_policy_uid_principal) end |