Class: Google::Apis::SecretmanagerV1beta1::Progress
- Inherits:
-
Object
- Object
- Google::Apis::SecretmanagerV1beta1::Progress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/secretmanager_v1beta1/classes.rb,
lib/google/apis/secretmanager_v1beta1/representations.rb,
lib/google/apis/secretmanager_v1beta1/representations.rb
Overview
Represents progress information for operations involving multiple secret versions.
Instance Attribute Summary collapse
-
#completed_version_count ⇒ Fixnum
Output only.
-
#failed_version_count ⇒ Fixnum
Output only.
-
#total_version_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Progress
constructor
A new instance of Progress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Progress
Returns a new instance of Progress.
748 749 750 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_version_count ⇒ Fixnum
Output only. Number of secret versions that have been successfully processed
so far.
Corresponds to the JSON property completedVersionCount
735 736 737 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 735 def completed_version_count @completed_version_count end |
#failed_version_count ⇒ Fixnum
Output only. Number of secret versions that failed to process.
Corresponds to the JSON property failedVersionCount
740 741 742 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 740 def failed_version_count @failed_version_count end |
#total_version_count ⇒ Fixnum
Output only. Provides the total number of secret versions to be processed by
the operation.
Corresponds to the JSON property totalVersionCount
746 747 748 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 746 def total_version_count @total_version_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
753 754 755 756 757 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 753 def update!(**args) @completed_version_count = args[:completed_version_count] if args.key?(:completed_version_count) @failed_version_count = args[:failed_version_count] if args.key?(:failed_version_count) @total_version_count = args[:total_version_count] if args.key?(:total_version_count) end |