Class: Google::Apis::SecretmanagerV1beta1::Secret
- Inherits:
-
Object
- Object
- Google::Apis::SecretmanagerV1beta1::Secret
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/secretmanager_v1beta1/classes.rb,
lib/google/apis/secretmanager_v1beta1/representations.rb,
lib/google/apis/secretmanager_v1beta1/representations.rb
Overview
A Secret is a logical secret whose value and versions can be accessed. A Secret is made up of zero or more SecretVersions that represent the secret data.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
The labels assigned to this Secret.
-
#name ⇒ String
Output only.
-
#replication ⇒ Google::Apis::SecretmanagerV1beta1::Replication
A policy that defines the replication configuration of data.
-
#tags ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Secret
constructor
A new instance of Secret.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Secret
Returns a new instance of Secret.
880 881 882 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 880 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the Secret was created.
Corresponds to the JSON property createTime
849 850 851 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 849 def create_time @create_time end |
#labels ⇒ Hash<String,String>
The labels assigned to this Secret. Label keys must be between 1 and 63
characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform
to the following PCRE regular expression: \pLl\pLo0,62 Label values
must be between 0 and 63 characters long, have a UTF-8 encoding of maximum 128
bytes, and must conform to the following PCRE regular expression: [\pLl\p
Lo\pN_-]0,63`No more than 64 labels can be assigned to a given resource.
Corresponds to the JSON propertylabels`
859 860 861 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 859 def labels @labels end |
#name ⇒ String
Output only. The resource name of the Secret in the format projects/*/secrets/
*.
Corresponds to the JSON property name
865 866 867 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 865 def name @name end |
#replication ⇒ Google::Apis::SecretmanagerV1beta1::Replication
A policy that defines the replication configuration of data.
Corresponds to the JSON property replication
870 871 872 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 870 def replication @replication end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Mapping of Tag keys/values directly bound to
this resource. For example: "123/environment": "production", "123/costCenter":
"marketing" Tags are used to organize and group resources. Tags can be used to
control policy evaluation for the resource.
Corresponds to the JSON property tags
878 879 880 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 878 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
885 886 887 888 889 890 891 |
# File 'lib/google/apis/secretmanager_v1beta1/classes.rb', line 885 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @replication = args[:replication] if args.key?(:replication) @tags = args[:tags] if args.key?(:tags) end |