Class: Google::Apis::SecretmanagerV1beta1::SecretManagerService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::SecretmanagerV1beta1::SecretManagerService
- Defined in:
- lib/google/apis/secretmanager_v1beta1/service.rb
Overview
Secret Manager API
Stores sensitive data such as API keys, passwords, and certificates. Provides convenience while improving security.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://secretmanager.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#access_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::AccessSecretVersionResponse
Accesses a SecretVersion.
-
#add_project_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::SecretVersion
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
-
#create_project_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Secret
Creates a new Secret containing no SecretVersions.
-
#delete_project_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Empty
Deletes a Secret.
-
#destroy_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::SecretVersion
Destroys a SecretVersion.
-
#disable_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::SecretVersion
Disables a SecretVersion.
-
#enable_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::SecretVersion
Enables a SecretVersion.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Location
Gets information about a location.
-
#get_project_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Secret
Gets metadata for a given Secret.
-
#get_project_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Policy
Gets the access control policy for a secret.
-
#get_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::SecretVersion
Gets metadata for a SecretVersion.
-
#initialize ⇒ SecretManagerService
constructor
A new instance of SecretManagerService.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#list_project_secret_versions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::ListSecretVersionsResponse
Lists SecretVersions.
-
#list_project_secrets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::ListSecretsResponse
Lists Secrets.
-
#patch_project_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Secret
Updates metadata of an existing Secret.
-
#set_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Policy
Sets the access control policy on the specified secret.
-
#test_secret_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has for the specified secret.
Constructor Details
#initialize ⇒ SecretManagerService
Returns a new instance of SecretManagerService.
48 49 50 51 52 53 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-secretmanager_v1beta1', client_version: Google::Apis::SecretmanagerV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#access_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::AccessSecretVersionResponse
Accesses a SecretVersion. This call returns the secret data. projects/*/
secrets/*/versions/latest is an alias to the latest SecretVersion.
497 498 499 500 501 502 503 504 505 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 497 def access_project_secret_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}:access', ) command.response_representation = Google::Apis::SecretmanagerV1beta1::AccessSecretVersionResponse::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::AccessSecretVersionResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#add_project_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::SecretVersion
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 164 def add_project_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}:addVersion', ) command.request_representation = Google::Apis::SecretmanagerV1beta1::AddSecretVersionRequest::Representation command.request_object = add_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1beta1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::SecretVersion command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Secret
Creates a new Secret containing no SecretVersions.
202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 202 def create_project_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/secrets', ) command.request_representation = Google::Apis::SecretmanagerV1beta1::Secret::Representation command.request_object = secret_object command.response_representation = Google::Apis::SecretmanagerV1beta1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::Secret command.params['parent'] = parent unless parent.nil? command.query['secretId'] = secret_id unless secret_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Empty
Deletes a Secret.
236 237 238 239 240 241 242 243 244 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 236 def delete_project_secret(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1beta1::Empty::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#destroy_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::SecretVersion
Destroys a SecretVersion. Sets the state of the SecretVersion to DESTROYED and irrevocably destroys the secret data.
530 531 532 533 534 535 536 537 538 539 540 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 530 def destroy_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:destroy', ) command.request_representation = Google::Apis::SecretmanagerV1beta1::DestroySecretVersionRequest::Representation command.request_object = destroy_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1beta1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#disable_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::SecretVersion
Disables a SecretVersion. Sets the state of the SecretVersion to DISABLED.
564 565 566 567 568 569 570 571 572 573 574 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 564 def disable_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:disable', ) command.request_representation = Google::Apis::SecretmanagerV1beta1::DisableSecretVersionRequest::Representation command.request_object = disable_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1beta1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::SecretVersion
Enables a SecretVersion. Sets the state of the SecretVersion to ENABLED.
598 599 600 601 602 603 604 605 606 607 608 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 598 def enable_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:enable', ) command.request_representation = Google::Apis::SecretmanagerV1beta1::EnableSecretVersionRequest::Representation command.request_object = enable_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1beta1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 75 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1beta1::Location::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Secret
Gets metadata for a given Secret.
267 268 269 270 271 272 273 274 275 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 267 def get_project_secret(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1beta1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::Secret command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Policy
Gets the access control policy for a secret. Returns empty policy if the secret exists and does not have a policy set.
311 312 313 314 315 316 317 318 319 320 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 311 def get_project_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::SecretmanagerV1beta1::Policy::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::SecretVersion
Gets metadata for a SecretVersion. projects/*/secrets/*/versions/latest is
an alias to the latest SecretVersion.
633 634 635 636 637 638 639 640 641 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 633 def get_project_secret_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1beta1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 127 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::SecretmanagerV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_secret_versions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::ListSecretVersionsResponse
Lists SecretVersions. This call does not return secret data.
671 672 673 674 675 676 677 678 679 680 681 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 671 def list_project_secret_versions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/versions', ) command.response_representation = Google::Apis::SecretmanagerV1beta1::ListSecretVersionsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::ListSecretVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_secrets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::ListSecretsResponse
Lists Secrets.
350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 350 def list_project_secrets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/secrets', ) command.response_representation = Google::Apis::SecretmanagerV1beta1::ListSecretsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::ListSecretsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Secret
Updates metadata of an existing Secret.
386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 386 def patch_project_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::SecretmanagerV1beta1::Secret::Representation command.request_object = secret_object command.response_representation = Google::Apis::SecretmanagerV1beta1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::Secret command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::Policy
Sets the access control policy on the specified secret. Replaces any existing policy. Permissions on SecretVersions are enforced according to the policy set on the associated Secret.
424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 424 def set_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::SecretmanagerV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::SecretmanagerV1beta1::Policy::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_secret_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has for the specified secret. If the secret does not exist, this call returns an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission- aware UIs and command-line tools, not for authorization checking. This operation may "fail open" without warning.
463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/google/apis/secretmanager_v1beta1/service.rb', line 463 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::SecretmanagerV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::SecretmanagerV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |